@@ -1,6 +1,6 @@
-package StackTrace::Auto 0.200014;
+package StackTrace::Auto;
 # ABSTRACT: a role for generating stack traces during instantiation
-
+$StackTrace::Auto::VERSION = '0.201';
 use Moo::Role;
 use Sub::Quote ();
 use Module::Runtime 0.002 ();
@@ -133,7 +133,7 @@ StackTrace::Auto - a role for generating stack traces during instantiation
 
 =head1 VERSION
 
-version 0.200014
+version 0.201
 
 =head1 SYNOPSIS
 
@@ -152,6 +152,16 @@ First, include StackTrace::Auto in a Moose or Mooclass...
 
   print $obj->stack_trace->as_string;
 
+=head1 PERL VERSION SUPPORT
+
+This module has a long-term perl support period.  That means it will not
+require a version of perl released fewer than five years ago.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 ATTRIBUTES
 
 =head2 stack_trace
