@@ -1,6 +1,6 @@
-package Throwable 0.200014;
+package Throwable;
 # ABSTRACT: a role for classes that can be thrown
-
+$Throwable::VERSION = '0.201';
 use Moo::Role;
 use Sub::Quote ();
 use Scalar::Util ();
@@ -106,7 +106,7 @@ Throwable - a role for classes that can be thrown
 
 =head1 VERSION
 
-version 0.200014
+version 0.201
 
 =head1 SYNOPSIS
 
@@ -130,6 +130,16 @@ previous value for C<$@> and calls C<die $self>.
 Throwable is implemented with L<Moo>, so you can stick to Moo or use L<Moose>,
 as you prefer.
 
+=head1 PERL VERSION SUPPORT
+
+This module has a long-term perl support period.  That means it will not
+require a version of perl released fewer than five years ago.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 ATTRIBUTES
 
 =head2 previous_exception
