@@ -1,6 +1,6 @@
-package Throwable::Error 0.200014;
+package Throwable::Error;
 # ABSTRACT: an easy-to-use class for error objects
-
+$Throwable::Error::VERSION = '0.201';
 use Moo 1.000001;
 with 'Throwable', 'StackTrace::Auto';
 
@@ -114,7 +114,7 @@ Throwable::Error - an easy-to-use class for error objects
 
 =head1 VERSION
 
-version 0.200014
+version 0.201
 
 =head1 SYNOPSIS
 
@@ -152,6 +152,16 @@ roles.  That means you can call C<throw> on it to create and throw an error
 object in one call, and that every error object will have a stack trace for its
 creation.
 
+=head1 PERL VERSION SUPPORT
+
+This module has a long-term perl support period.  That means it will not
+require a version of perl released fewer than five years ago.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 ATTRIBUTES
 
 =head2 message
